TransformFunctions
==================

.. toctree::
   :maxdepth: 3

.. automodule:: psyneulink.core.components.functions.transformfunctions
   :members: Concatenate, Rearrange, Reduce, LinearCombination, CombineMeans, MatrixTransform, PredictionErrorDeltaFunction
   :private-members:
   :exclude-members: Parameters

